package com.caimei.mapper;

import com.caimei.model.po.*;
import com.caimei.model.vo.AddressVo;
import com.caimei.model.vo.CartProductVo;
import com.caimei.model.vo.CityVo;
import com.caimei.model.vo.ShopVo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * Description
 *
 * @author : plf
 * @date : 2021/3/24
 */
@Mapper
public interface OrderSubmitMapper {
    /**
     * 查询商品结算供应商
     *
     * @param productIds
     * @return
     */
    List<ShopVo> findShopByproductIds(@Param("productIds") String[] productIds);

    /**
     * 查询商品购物车信息
     *
     * @param shopId
     * @param productIds
     * @param userId
     * @return
     */
    List<CartProductVo> findProductListByCart(@Param("shopId") Integer shopId, @Param("productIds") String[] productIds, @Param("userId") Integer userId);

    /**
     * 查询商品信息
     *
     * @param productId
     * @return
     */
    CartProductVo findCartByProductId(String productId);

    /**
     * 查询用户发票信息
     *
     * @param userId
     * @return
     */
    CmUserInvoiceInfoPo findUserInvoice(Integer userId);

    /**
     * 查询供应商信息
     *
     * @param shopId
     * @return
     */
    ShopVo getShop(Integer shopId);

    /**
     * 查询用户信息
     *
     * @param userId
     * @return
     */
    UserPo findUser(Integer userId);

    /**
     * 保存主订单信息
     *
     * @param order
     */
    void insertOrder(CmOrderPo order);

    /**
     * 保存订单促销信息
     *
     * @param promotions
     */
    void insertOrderPromotions(PromotionsPo promotions);

    /**
     * 查询订单促销表
     *
     * @param orderId
     * @param promotionsId
     * @return
     */
    PromotionsPo findOrderPromotions(@Param("orderId") Long orderId, @Param("promotionsId") Integer promotionsId);

    /**
     * 查询子订单编号
     *
     * @param orderId
     * @return
     */
    String findMaxShopOrderNo(Long orderId);

    /**
     * 保存子订单信息
     *
     * @param shopOrder
     */
    void insertShopOrder(CmShopOrderPo shopOrder);

    /**
     * 保存订单商品信息
     *
     * @param orderProduct
     */
    void insertOrderProduct(CmOrderProductPo orderProduct);

    /**
     * 保存订单阶梯价格信息
     *
     * @param ladderPrice
     */
    void insertOrderProductLadderPrice(OrderProductLadderPricePo ladderPrice);

    /**
     * 更新主订单数据
     *
     * @param order
     */
    void updateOrder(CmOrderPo order);

    /**
     * 查询订单发票信息
     *
     * @param orderId
     * @return
     */
    BpOrderInvoicePo getOrderInvoice(Long orderId);

    /**
     * 保存订单地址信息
     *
     * @param userInfo
     */
    void insertUserInfo(BpOrderUserInfoPo userInfo);

    /**
     * 更新订单发票信息
     *
     * @param invoice
     */
    void updateOrderInvoice(BpOrderInvoicePo invoice);

    /**
     * 保存订单发票信息
     *
     * @param invoice
     */
    void insertOrderInvoice(BpOrderInvoicePo invoice);

    /**
     * 查询地址信息
     *
     * @param addressId
     * @return
     */
    AddressVo findByAddressId(Integer addressId);
}
